@@ -22,10 +22,6 @@ ch.setFormatter(formatter)
 logger.addHandler(ch)
 logger.setLevel(logging.INFO)
 
-ATLAS_ADDR = "mongodb+srv://hj3415:piyrw421@nfs.2mnb4.mongodb.net/005930?retryWrites=true&w=majority"
-INTERNAL_NET_ADDR = 'mongodb://192.168.0.173:27017'
-LOCAL_ADDR = 'mongodb://localhost:27017'
-
 
 def connect_mongo(addr: str, timeout=5):
     # 클라이언트 한개로 데이터베이스를 다루는게 효율적이라 함수를 따로 뺐음.
@@ -38,6 +34,8 @@ def connect_mongo(addr: str, timeout=5):
         client = pymongo.MongoClient(addr, serverSelectionTimeoutMS=timeout * 1000)
     elif addr.startswith('mongodb+srv://'):
         client = pymongo.MongoClient(addr, serverSelectionTimeoutMS=timeout * 1000, tlsCAFile=ca)
+    else:
+        raise Exception(f"Invalid address: {addr}")
     try:
         srv_info = client.server_info()
         conn_str = f"Connect to Mongo Atlas v{srv_info['version']}..."
@@ -385,6 +383,20 @@ class Corps(Atlas):
         else:
             raise Exception(f'Invalid value : {page}({self.COL_TITLE})')
 
+    @staticmethod
+    def refine_dict(data: dict, refine_words: list) -> dict:
+        """
+        검색된 raw 딕셔너리에서 불필요한 항목들
+        ex - ['_id', '항목', '전년대비', '전년대비1', '전분기대비', '전분기대비1']
+        을 삭제한다.
+        """
+        for del_title in refine_words:
+            try:
+                del data[del_title]
+            except KeyError:
+                pass
+        return data
+
     # ========================End Properties=======================
 
     def get_all_corps(self) -> list:
@@ -624,47 +636,54 @@ class CDart(Corps):
             logger.error(f'Error occurred while delete dart data..')
 
 
-class C106Y(Corps):
+class C106(Corps):
+    def save(self, c106_data: pd.DataFrame) -> bool:
+        self.client[self.code][self.page].create_index('항목', unique=True)
+        self.clear_col()
+        return super(C106, self)._save_df(c106_data)
+
+    def load(self) -> pd.DataFrame:
+        return super(C106, self)._load_df()
+
+    def get_all_titles(self) -> list:
+        titles = []
+        for item in self.get_docs():
+            titles.append(item['항목'])
+        return list(set(titles))
+
+    def find(self, title: str) -> dict:
+        """
+        title에 해당하는 항목을 딕셔너리로 반환한다.
+        """
+        titles = self.get_all_titles()
+        if title in titles:
+            data = self.client[self.code][self.page].find_one({'항목': {'$eq': title}})
+            return self.refine_dict(data, ['_id', '항목'])
+        else:
+            raise Exception(f'{title} is not in {titles}')
+
+
+class C106Y(C106):
     def __init__(self, client, code: str):
         """
-
          Args:
             code (str): 종목코드(디비명)
-            page (str): c106y
         """
         super(C106Y, self).__init__(client)
         self.code = code
         self.page = 'c106y'
 
-    def save(self, c106_data: pd.DataFrame) -> bool:
-        self.client[self.code][self.page].create_index('항목', unique=True)
-        self.clear_col()
-        return super(C106Y, self)._save_df(c106_data)
 
-    def load(self) -> pd.DataFrame:
-        return super(C106Y, self)._load_df()
-
-
-class C106Q(Corps):
+class C106Q(C106):
     def __init__(self, client, code: str):
         """
-
          Args:
             code (str): 종목코드(디비명)
-            page (str): c106q
         """
         super(C106Q, self).__init__(client)
         self.code = code
         self.page = 'c106q'
 
-    def save(self, c106_data: pd.DataFrame) -> bool:
-        self.client[self.code][self.page].create_index('항목', unique=True)
-        self.clear_col()
-        return super(C106Q, self)._save_df(c106_data)
-
-    def load(self) -> pd.DataFrame:
-        return super(C106Q, self)._load_df()
-
 
 class C108(Corps):
     def __init__(self, client, code: str):
@@ -734,20 +753,6 @@ class C1034(Corps, metaclass=ABCMeta):
             sum_dict[period] = sum(utils.nan_to_zero(data[period]) for data in data_list)
         return sum_dict
 
-    @staticmethod
-    def refine_dict(data: dict, refine_words: list) -> dict:
-        """
-        검색된 raw 딕셔너리에서 불필요한 항목들
-        ex - ['_id', '항목', '전년대비', '전년대비1', '전분기대비', '전분기대비1']
-        을 삭제한다.
-        """
-        for del_title in refine_words:
-            try:
-                del data[del_title]
-            except KeyError:
-                pass
-        return data
-
     def _find(self, title: str, refine_words: list) -> Tuple[List[dict], int]:
         """
         title인자에 해당하는 항목을 검색하여 반환한다.
@@ -867,7 +872,7 @@ class C1034(Corps, metaclass=ABCMeta):
 
             if len(od_q) < 4:
                 # od_q의 값이 4개 이하이면 그냥 최근 연도의 값으로 반환한다.
-                y = C1034(client)
+                y = C1034(self.client)
                 y.code = self.code
                 y.page = self.col[:-1] + 'y'
                 return y.latest_value(title)
@@ -1002,10 +1007,3 @@ class C104(C1034):
         l, c = super(C104, self)._find(title, ['_id', '항목', '전년대비', '전년대비1', '전분기대비', '전분기대비1'])
         return l[0]
 
-
-if __name__ == "__main__":
-    atlas_addr = "mongodb+srv://hj3415:piyrw421@nfs.2mnb4.mongodb.net/005930?retryWrites=true&w=majority"
-    local_addr = 'mongodb://localhost:27017'
-
-    client = connect_mongo(atlas_addr)
-    Atlas(client).initiate_db()
